@@ -89,7 +89,7 @@ class TestParser(unittest.TestCase):
 
     def test_parser_no_default(self):
         parser = create_parser()
-        args = parser.parse_args()
+        args = parser.parse_args([])
         self.assertEqual(args.add_default, None)
 
 
