@@ -6,17 +6,16 @@
 """A collector for grabbing appropriately tagged events from MISP.
 
 Parameters:
-  - misp_url: URL of the MISP server
-  - misp_key: API key for accessing MISP
-  - misp_tag_to_process: MISP tag identifying events to be processed
-  - misp_tag_processed: MISP tag identifying events that have been processed
+    misp_url: URL of the MISP server
+    misp_key: API key for accessing MISP
+    misp_tag_to_process: MISP tag identifying events to be processed
+    misp_tag_processed: MISP tag identifying events that have been processed
 
 
-PyMISP versions released after January 2020 will no longer support the
-"old" PyMISP class.
+PyMISP versions released after January 2020 will no longer support the "old" PyMISP class.
 For compatibility:
- * older versions of pymisp still work with this bot
- * the deprecated parameter `misp_verify` will create a DeprecationWarning
+* older versions of pymisp still work with this bot
+* the deprecated parameter `misp_verify` will create a DeprecationWarning
 """
 import json
 import warnings
