@@ -24,7 +24,7 @@ class RsyncCollectorBot(CollectorBot):
             pass
 
     def process(self):
-        self.logger.info("Updating file {}.".format(self.file))
+        self.logger.info(f"Updating file {self.file}.")
         process = run(["rsync", path.join(self.rsync_path, self.file),
                        self.temp_directory],
                       stderr=PIPE)
@@ -34,7 +34,7 @@ class RsyncCollectorBot(CollectorBot):
                                        process.returncode,
                                        process.stderr))
         report = self.new_report()
-        with open(path.join(self.temp_directory, self.file), "r") as rsync_file:
+        with open(path.join(self.temp_directory, self.file)) as rsync_file:
             report.add("raw", rsync_file.read())
             self.send_message(report)
 
