@@ -5,69 +5,82 @@ SPDX-FileCopyrightText: 2020 Intelmq Team <intelmq-team@cert.at>
 SPDX-License-Identifier: AGPL-3.0-or-later
 """
 from datetime import datetime, timedelta
+import json
 import hashlib
 import hmac
 import re
+from typing import Optional
 
 import requests.exceptions
 
 from intelmq.lib.bot import CollectorBot
-from intelmq.lib.cache import Cache
-from intelmq.lib.utils import create_request_session
+from intelmq.lib.mixins import HttpMixin, CacheMixin
+
 
 APIROOT = 'https://transform.shadowserver.org/api2/'
+DLROOT  = 'https://dl.shadowserver.org/'
 FILENAME_PATTERN = re.compile(r'\.csv$')
 
 
-class ShadowServerAPICollectorBot(CollectorBot):
+class ShadowServerAPICollectorBot(CollectorBot, HttpMixin, CacheMixin):
     """
-    Shadowserver Reports API Collector Bot
+    Connects to the Shadowserver API, requests a list of all the reports for an organization and processes the ones that are new
 
-    Parameters
-    ----------
-    api_key: str
-        Your Shadowserver API key
-    secret: str
-        Your Shadowserver API secret
-    country: str
-        The country you want to download reports for (i.e. 'austria')
-    types: list
-        A list of strings or a string of comma-separated values with the names of reporttypes you want to process. If you leave this empty, all the available reports will be downloaded and processed (i.e. 'scan', 'drones', 'intel', 'sandbox_connection', 'sinkhole_combined').
+    Parameters:
+        api_key (str): Your Shadowserver API key
+        secret (str): Your Shadowserver API secret
+        country (str): DEPRECIATED The mailing list you want to download reports for (i.e. 'austria')
+        reports (list):
+            A list of strings or a comma-separated list of the mailing lists you want to process.
+        types (list):
+            A list of strings or a string of comma-separated values with the names of reporttypes you want to process. If you leave this empty, all the available reports will be downloaded and processed (i.e. 'scan', 'drones', 'intel', 'sandbox_connection', 'sinkhole_combined').
+        file_format (str): File format to download ('csv' or 'json').  The default is 'json' for compatibility. Using 'csv' is recommended for best performance.
     """
 
+    country = None
+    api_key = None
+    secret = None
+    types = None
+    reports = None
+    file_format = None
+    rate_limit: int = 86400
+    redis_cache_db: int = 12
+    redis_cache_host: str = "127.0.0.1"  # TODO: type could be ipadress
+    redis_cache_port: int = 6379
+    redis_cache_ttl: int = 864000  # 10 days
+    redis_cache_password: Optional[str] = None
+    _report_list = []
+
     def init(self):
-        self.apikey = getattr(self.parameters, "api_key", None)
-        if self.apikey is None:
+        if self.api_key is None:
             raise ValueError('No api_key provided.')
-        self.secret = getattr(self.parameters, "secret", None)
         if self.secret is None:
             raise ValueError('No secret provided.')
-        self.country = getattr(self.parameters, "country", None)
-        if self.country is None:
-            raise ValueError('No country provided.')
 
-        self.types = getattr(self.parameters, 'types', None)
-        if isinstance(self.types, str):
-            self.types = self.types.split(',')
+        if isinstance(self.reports, str):
+            self._report_list = self.reports.split(',')
+        elif isinstance(self.reports, list):
+            self._report_list = self.reports
 
-        self.preamble = '{{ "apikey": "{}" '.format(self.apikey)
+        if self.country is not None and self.country not in self._report_list:
+            self.logger.warn("Deprecated parameter 'country' found. Please use 'reports' instead. The backwards-compatibility will be removed in IntelMQ version 4.0.0.")
+            self._report_list.append(self.country)
 
-        self.set_request_parameters()
-        self.session = create_request_session(self)
+        if self.file_format is not None:
+            if not (self.file_format == 'csv' or self.file_format == 'json'):
+                raise ValueError('Invalid file_format')
+        else:
+            self.file_format = 'json'
+            self.logger.info("For best performance, set 'file_format' to 'csv' and use intelmq.bots.parsers.shadowserver.parser.")
 
-        self.cache = Cache(self.parameters.redis_cache_host,
-                           self.parameters.redis_cache_port,
-                           self.parameters.redis_cache_db,
-                           getattr(self.parameters, 'redis_cache_ttl', 864000),  # 10 days
-                           getattr(self.parameters, "redis_cache_password", None)
-                           )
+        self.preamble = f'{{ "apikey": "{self.api_key}" '
 
     def _headers(self, data):
         return {'HMAC2': hmac.new(self.secret.encode(), data.encode('utf-8'), digestmod=hashlib.sha256).hexdigest()}
 
     def _reports_list(self, date=None):
         """
-        Get a list of all the reports shadowserver has for a specific country
+        Get a list of all the reports shadowserver has for an organization
         via the reports/list endpoint. If a list of types is set in the
         parameters, we only process reports with those types.
         To be on the safe side regarding different calculations of timestamps,
@@ -82,12 +95,13 @@ class ShadowServerAPICollectorBot(CollectorBot):
         dayafter = date + timedelta(1)
 
         data = self.preamble
-        data += ',"report": ["{}"] '.format(self.country)
-        data += ',"date": "{}:{}" '.format(daybefore.isoformat(), dayafter.isoformat())
+        data += f',"date": "{daybefore.isoformat()}:{dayafter.isoformat()}" '
+        if len(self._report_list) > 0:
+            data += f',"reports": {json.dumps(self._report_list)}'
         data += '}'
         self.logger.debug('Downloading report list with data: %s.', data)
 
-        response = self.session.post(APIROOT + 'reports/list', data=data, headers=self._headers(data))
+        response = self.http_session().post(APIROOT + 'reports/list', data=data, headers=self._headers(data))
         response.raise_for_status()
 
         reports = response.json()
@@ -107,10 +121,13 @@ class ShadowServerAPICollectorBot(CollectorBot):
         Download one report from the shadowserver API via the reports/download endpoint
         """
         data = self.preamble
-        data += ',"id": "{}"}}'.format(reportid)
+        data += f',"id": "{reportid}"}}'
         self.logger.debug('Downloading report with data: %s.', data)
 
-        response = self.session.post(APIROOT + 'reports/download', data=data, headers=self._headers(data))
+        if (self.file_format == 'json'):
+            response = self.http_session().post(APIROOT + 'reports/download', data=data, headers=self._headers(data))
+        else:
+            response = self.http_session().get(DLROOT + reportid)
         response.raise_for_status()
 
         return response.text
@@ -127,8 +144,8 @@ class ShadowServerAPICollectorBot(CollectorBot):
 
         for item in reportslist:
             filename = item['file']
-            filename_fixed = FILENAME_PATTERN.sub('.json', filename, count=1)
-            if self.cache.get(filename):
+            filename_fixed = FILENAME_PATTERN.sub('.' + self.file_format, filename, count=1)
+            if self.cache_get(filename):
                 self.logger.debug('Processed file %r (fixed: %r) already.', filename, filename_fixed)
                 continue
             self.logger.debug('Processing file %r (fixed: %r).', filename, filename_fixed)
@@ -138,7 +155,7 @@ class ShadowServerAPICollectorBot(CollectorBot):
                 report.add('extra.file_name', filename_fixed)
                 report.add('raw', reportdata)
                 self.send_message(report)
-                self.cache.set(filename, 1)
+                self.cache_set(filename, 1)
                 self.logger.debug('Sent report: %r (fixed: %r, size: %.3g KiB).', filename, filename_fixed,
                                   len(reportdata) / 1024)  # TODO: Replace by a generic size-conversion function
                 reports_downloaded += 1
