@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2018 Karel
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 """
 Twitter Collector Bot
 
@@ -36,66 +40,64 @@ import time
 from urllib.parse import urlsplit
 
 from intelmq.lib.bot import CollectorBot
-from intelmq.lib.utils import create_request_session
+from intelmq.lib.mixins import HttpMixin
 from intelmq.lib.exceptions import MissingDependencyError
 
-try:
-    import requests
-except ImportError:
-    requests = None
-
 try:
     import twitter
 except ImportError:
     twitter = None
 
 
-class TwitterCollectorBot(CollectorBot):
+class TwitterCollectorBot(CollectorBot, HttpMixin):
+    "Collect tweets from given target timelines"
+    access_token_key: str = ""
+    access_token_secret: str = ""
+    consumer_key: str = ""
+    consumer_secret: str = ""
+    default_scheme: str = "http"
+    exclude_replies: bool = False
+    follow_urls: str = ""
+    include_rts: bool = True
+    target_timelines: str = ""
+    timelimit: int = 24 * 60 * 60
+    tweet_count: int = 20
+    _target_timelines = []
+    _follow_urls = []
 
     def init(self):
-        if requests is None:
-            raise MissingDependencyError("requests")
         if twitter is None:
             raise MissingDependencyError("twitter")
         self.current_time_in_seconds = int(time.time())
-        self.target_timelines = []
-        if getattr(self.parameters, "target_timelines", '') != '':
-            self.target_timelines.extend(
-                self.parameters.target_timelines.split(','))
-        self.tweet_count = int(getattr(self.parameters, "tweet_count", 20))
-        self.follow_urls = []
-        if getattr(self.parameters, "follow_urls", '') != '':
-            self.follow_urls.extend(
-                self.parameters.follow_urls.split(','))
-        self.include_rts = getattr(self.parameters, "include_rts", False)
-        self.exclude_replies = getattr(self.parameters, "exclude_replies", False)
-        self.timelimit = int(getattr(self.parameters, "timelimit", 24 * 60 * 60))
+        if self.target_timelines != '':
+            self._target_timelines.extend(
+                self.target_timelines.split(','))
+        if self.follow_urls != '':
+            self._follow_urls.extend(
+                self.follow_urls.split(','))
         self.api = twitter.Api(
-            consumer_key=self.parameters.consumer_key,
-            consumer_secret=self.parameters.consumer_secret,
-            access_token_key=self.parameters.access_token_key,
-            access_token_secret=self.parameters.access_token_secret,
+            consumer_key=self.consumer_key,
+            consumer_secret=self.consumer_secret,
+            access_token_key=self.access_token_key,
+            access_token_secret=self.access_token_secret,
             tweet_mode="extended")
 
-        self.set_request_parameters()
-        self.session = create_request_session(self)
-
     def get_text_from_url(self, url: str) -> str:
-        # netloc could include the port explicityly, but we ignore that improbable case here
+        # netloc could include the port explicitly, but we ignore that improbable case here
         netloc = urlsplit(url).netloc
         if netloc == "pastebin.com" or netloc.endswith('.pastebin.com'):
             self.logger.debug('Processing url %r.', url)
             if "raw" not in url:
-                request = self.session.get(
+                request = self.http_get(
                     url.replace("pastebin.com", "pastebin.com/raw", count=1))
             else:
-                request = self.session.get(url)
+                request = self.http_get(url)
             return request.text
         return ''
 
     def process(self):
         tweets = []
-        for target in self.target_timelines:
+        for target in self._target_timelines:
             statuses = self.api.GetUserTimeline(
                 screen_name=target,
                 count=self.tweet_count,
@@ -112,9 +114,9 @@ class TwitterCollectorBot(CollectorBot):
             report.add('raw', tweet.full_text)
             report.add(
                 'feed.url',
-                'https://twitter.com/{}/status/{}'.format(tweet.user.screen_name, tweet.id))
+                f'https://twitter.com/{tweet.user.screen_name}/status/{tweet.id}')
             self.send_message(report)
-            if tweet.user.screen_name in self.follow_urls:
+            if tweet.user.screen_name in self._follow_urls:
                 if len(tweet.urls) > 0:
                     text = ''
                     for source in tweet.urls:
@@ -125,7 +127,7 @@ class TwitterCollectorBot(CollectorBot):
                         report.add('feed.code', 'url_text')
                         report.add(
                             'feed.url',
-                            'https://twitter.com/{}/status/{}'.format(tweet.user.screen_name, tweet.id))
+                            f'https://twitter.com/{tweet.user.screen_name}/status/{tweet.id}')
                         self.send_message(report)
 
 
