@@ -5,16 +5,15 @@
 # -*- coding: utf-8 -*-
 
 import re
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
-import pytz
 from dateutil import parser
 
-from intelmq.lib.bot import Bot
+from intelmq.lib.bot import ExpertBot
 from intelmq.lib.utils import parse_relative, TIMESPANS
 
 
-class FilterExpertBot(Bot):
+class FilterExpertBot(ExpertBot):
     """Filter events, supports named paths for splitting the message flow"""
 
     _message_processed_verb = 'Forwarded'
@@ -79,7 +78,7 @@ class FilterExpertBot(Bot):
         # time based filtering
         if self.time_filter and 'time.source' in event:
             try:
-                event_time = parser.parse(str(event.get('time.source'))).replace(tzinfo=pytz.timezone('UTC'))
+                event_time = parser.parse(str(event.get('time.source'))).replace(tzinfo=timezone.utc)
             except ValueError:
                 self.logger.error("Could not parse time.source %s.", event.get('time.source'))
             else:
@@ -92,7 +91,7 @@ class FilterExpertBot(Bot):
                     self.logger.debug("Filtered out event with time.source %r.", event.get('time.source'))
                     return
 
-                now = datetime.now(tz=pytz.timezone('UTC'))
+                now = datetime.now(tz=timezone.utc)
                 if type(self.not_after) is timedelta and event_time > (now - self.not_after):
                     self.acknowledge_message()
                     self.logger.debug("Filtered out event with time.source %r.", event.get('time.source'))
