@@ -14,7 +14,7 @@ import pathlib
 import requests
 import tarfile
 
-from intelmq.lib.bot import Bot
+from intelmq.lib.bot import ExpertBot
 from intelmq.lib.exceptions import MissingDependencyError
 from intelmq.lib.utils import get_bots_settings, create_request_session
 from intelmq.bin.intelmqctl import IntelMQController
@@ -25,12 +25,13 @@ except ImportError:
     geoip2 = None
 
 
-class GeoIPExpertBot(Bot):
+class GeoIPExpertBot(ExpertBot):
     """Add geolocation information from a local MaxMind database to events (country, city, longitude, latitude)"""
     database: str = "/opt/intelmq/var/lib/bots/maxmind_geoip/GeoLite2-City.mmdb"  # TODO: should be pathlib.Path
     license_key: str = "<insert Maxmind license key>"
     overwrite: bool = False
     use_registered: bool = False
+    autoupdate_cached_database: bool = True  # Activate/deactivate update-database functionality
 
     def init(self):
         if geoip2 is None:
@@ -38,7 +39,7 @@ class GeoIPExpertBot(Bot):
 
         try:
             self.database = geoip2.database.Reader(self.database)
-        except IOError:
+        except OSError:
             self.logger.exception("GeoIP Database does not exist or could not "
                                   "be accessed in %r.",
                                   self.database)
@@ -113,12 +114,12 @@ class GeoIPExpertBot(Bot):
         runtime_conf = get_bots_settings()
         try:
             for bot in runtime_conf:
-                if runtime_conf[bot]["module"] == __name__:
+                if runtime_conf[bot]["module"] == __name__ and runtime_conf[bot]['parameters'].get('autoupdate_cached_database', True):
                     license_key = runtime_conf[bot]["parameters"]["license_key"]
                     bots[bot] = runtime_conf[bot]["parameters"]["database"]
 
         except KeyError as e:
-            error = "Database update failed. Your configuration of {0} is missing key {1}.".format(bot, e)
+            error = f"Database update failed. Your configuration of {bot} is missing key {e}."
             if str(e) == "'license_key'":
                 error += "\n"
                 error += "Since December 30, 2019 you need to register for a free license key to access GeoLite2 database.\n"
@@ -129,7 +130,7 @@ class GeoIPExpertBot(Bot):
 
         if not bots:
             if verbose:
-                print("Database update skipped. No bots of type {0} present in runtime.conf.".format(__name__))
+                print(f"Database update skipped. No bots of type {__name__} present in runtime configuration or database update disabled with parameter 'autoupdate_cached_database'.")
             sys.exit(0)
 
         # we only need to import now, if there are no maxmind_geoip bots, this dependency does not need to be installed
@@ -151,14 +152,14 @@ class GeoIPExpertBot(Bot):
                                        "suffix": "tar.gz"
                                    })
         except requests.exceptions.RequestException as e:
-            sys.exit("Database update failed. Connection Error: {0}".format(e))
+            sys.exit(f"Database update failed. Connection Error: {e}")
 
         if response.status_code == 401:
             sys.exit("Database update failed. Your license key is invalid.")
 
         if response.status_code != 200:
-            sys.exit("Database update failed. Server responded: {0}.\n"
-                     "URL: {1}".format(response.status_code, response.url))
+            sys.exit("Database update failed. Server responded: {}.\n"
+                     "URL: {}".format(response.status_code, response.url))
 
         database_data = None
 
