@@ -10,9 +10,10 @@ import dns.exception
 import dns.resolver
 import dns.reversename
 
-from intelmq.lib.bot import Bot
+from intelmq.lib.bot import ExpertBot
 from intelmq.lib.harmonization import IPAddress
 from intelmq.lib.mixins import CacheMixin
+from intelmq.lib.utils import resolve_dns
 
 MINIMUM_BGP_PREFIX_IPV4 = 24
 MINIMUM_BGP_PREFIX_IPV6 = 128
@@ -23,7 +24,7 @@ class InvalidPTRResult(ValueError):
     pass
 
 
-class ReverseDnsExpertBot(Bot, CacheMixin):
+class ReverseDnsExpertBot(ExpertBot, CacheMixin):
     """Get the correspondent domain name for source and destination IP address"""
     cache_ttl_invalid_response: int = 60
     overwrite: bool = False
@@ -67,7 +68,7 @@ class ReverseDnsExpertBot(Bot, CacheMixin):
             else:
                 rev_name = dns.reversename.from_address(ip)
                 try:
-                    results = dns.resolver.query(rev_name, "PTR")
+                    results = resolve_dns(rev_name, "PTR")
                     expiration = results.expiration
                     for result in results:
                         # use first valid result
