@@ -1,14 +1,19 @@
+# SPDX-FileCopyrightText: 2018 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import re
 
 from intelmq.lib import utils
 from intelmq.lib.bot import ParserBot
+from intelmq.lib.harmonization import FQDN
 
 MAPPING_STATIC = {'bot': {
     'classification.type': 'infected-system'},
     'bruteforce': {'classification.type': 'brute-force'},
     'controller': {
-    'classification.type': 'c2server'},
+    'classification.type': 'c2-server'},
     'darknet': {'classification.type': 'scanner',
                 'classification.identifier': 'darknet'},
     'phishing': {'classification.type': 'phishing',
@@ -16,11 +21,11 @@ MAPPING_STATIC = {'bot': {
     'proxy': {'classification.type': 'proxy',
               'classification.identifier': 'openproxy'},
     'honeypot': {'classification.type': 'scanner'},
-    'openresolvers': {'classification.type': 'vulnerable service',
+    'openresolvers': {'classification.type': 'vulnerable-system',
                       'classification.identifier': 'dns-open-resolver',
                       'protocol.application': 'dns',
                       },
-    'openresolver': {'classification.type': 'vulnerable service',
+    'openresolver': {'classification.type': 'vulnerable-system',
                      'classification.identifier': 'dns-open-resolver',
                      'protocol.application': 'dns',
                      },
@@ -45,6 +50,7 @@ DESTINATION_PORT_NUMBERS_TOTAL = re.compile(r' \(total_count:\d+\)$')
 
 
 class CymruCAPProgramParserBot(ParserBot):
+    """Parse the Cymru CAP Program feed"""
 
     def parse(self, report):
         lines = utils.base64_decode(report.get("raw")).splitlines()
@@ -85,7 +91,7 @@ class CymruCAPProgramParserBot(ParserBot):
             elif kind in ('destaddr', 'dstaddr'):
                 event['destination.ip'] = value
             else:
-                raise ValueError('Unknown value in comment %r for report %r.' % (kind, report_type))
+                raise ValueError(f'Unknown value in comment {kind!r} for report {report_type!r}.')
         if event_comment:
             event.add('event_description.text', ' '.join(event_comment))
 
@@ -102,7 +108,7 @@ class CymruCAPProgramParserBot(ParserBot):
         event.add('raw', self.recover_line(line))
         if report_type == 'beagle':  # TODO: verify
             # beagle|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS|[<GET REQUEST>] [srcport <PORT>]|ASNAME
-            event.add('classification.type', 'malware')
+            event.add('classification.type', 'infected-system')
             event.add('classification.identifier', 'beagle')
             event.add('malware.name', 'beagle')
             if len(comments):
@@ -119,7 +125,7 @@ class CymruCAPProgramParserBot(ParserBot):
             # phatbot|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS||ASNAME
             # sinit|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS||ASNAME
             # slammer|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS||ASNAME
-            event.add('classification.type', 'malware')
+            event.add('classification.type', 'infected-system')
             event.add('classification.identifier', report_type)
             event.add('malware.name', report_type)
         elif report_type == 'bots':
@@ -138,24 +144,24 @@ class CymruCAPProgramParserBot(ParserBot):
             raise NotImplementedError('Report %r not implemented, format is unknown.' % report_type)
         elif report_type == 'defacement':  # TODO: verify
             # defacement|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS|<URL> [<ZONE-H ID>]|ASNAME
-            event['classification.type'] = 'compromised'
+            event['classification.type'] = 'unauthorised-information-modification'
             event['classification.identifier'] = report_type
             event['source.url'] = comment_split[0]
             event['extra.zoneh.id'] = comment_split[1]
         elif report_type == 'fastflux':  # TODO: verify
             # fastflux|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS|[<DOMAIN>]|ASNAME
-            event['classification.type'] = 'compromised'
+            event['classification.type'] = 'system-compromise'
             event['classification.identifier'] = report_type
             if comments:
                 event['source.reverse_dns'] = comments
         elif report_type == 'malwareurl':  # TODO: verify
             # malwareurl|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS|<URL> <SCAN-ID>|ASNAME
             event['source.url'] = comment_split[0]
-            event.add('classification.type', 'malware')
+            event.add('classification.type', 'malware-distribution')
             event.add('classification.identifier', 'malwareurl')
         elif report_type == 'openresolvers':
             # openresolvers|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS||ASNAME
-            event['classification.type'] = 'vulnerable service'
+            event['classification.type'] = 'vulnerable-system'
             event['classification.identifier'] = 'dns-open-resolver'
             event['protocol.application'] = 'dns'
         elif report_type == 'phishing':
@@ -171,7 +177,7 @@ class CymruCAPProgramParserBot(ParserBot):
             event['extra.request'] = comments
         elif report_type == 'routers':  # TODO: verify
             # routers|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS|[<DEVICE TYPE>]|ASNAME
-            event['classification.type'] = 'compromised'
+            event['classification.type'] = 'system-compromise'
             if comments:
                 event['classification.identifier'] = comments
         elif report_type == 'scanners':  # TODO: verify
@@ -200,7 +206,7 @@ class CymruCAPProgramParserBot(ParserBot):
             event.add('source.url', comment_split[0])
             if len(comment_split == 2):
                 event.add('malware.hash.md5', comment_split[1])
-            event.add('classification.type', 'malware')
+            event.add('classification.type', 'malware-distribution')
             event.add('classification.identifier', 'spreader')
         elif report_type == 'stormworm':  # TODO: verify
             # stormworm|192.0.2.1|ASN|YYYY-MM-DD HH:MM:SS|confidence:<NUMBER> [legacy|crypto] [srcport <SOURCE PORT>]|ASNAME
@@ -250,10 +256,7 @@ class CymruCAPProgramParserBot(ParserBot):
         if bogus:
             span = bogus.span()
             groups = bogus.groups()
-            notes = '%shostname: %s; port: %s%s' % (notes[:span[0]],
-                                                    groups[0],
-                                                    groups[1],
-                                                    notes[span[1]:])
+            notes = f'{notes[:span[0]]}hostname: {groups[0]}; port: {groups[1]}{notes[span[1]:]}'
 
         comment_split = list(filter(lambda x: x, notes.split(';')))
         asninfo_split = asninfo.split(', ')
@@ -294,7 +297,7 @@ class CymruCAPProgramParserBot(ParserBot):
                             pass
                         else:
                             break
-                    raise ValueError('Unable to parse comment %r of category %r. Please report this.' % (comment, category))
+                    raise ValueError(f'Unable to parse comment {comment!r} of category {category!r}. Please report this.')
             key, value = comment.split(':', 1)
             key = key.strip()
             value = value.strip()
@@ -318,6 +321,8 @@ class CymruCAPProgramParserBot(ParserBot):
                         raise ValueError('Unknown protocol %r, please report a bug'
                                          '' % value)
             elif key == 'hostname':
+                if not FQDN.is_valid(value=value) and value == ip:
+                    continue
                 event['source.fqdn'] = value
             elif key == 'proxy_type':
                 if '-' in value:
@@ -333,7 +338,7 @@ class CymruCAPProgramParserBot(ParserBot):
             elif key == 'additional_asns':
                 event['extra.source.asns'] = [event['source.asn']] + list(map(int, value.split(',')))
             else:
-                raise ValueError('Unknown key %r in comment of category %r. Please report this.' % (key, category))
+                raise ValueError(f'Unknown key {key!r} in comment of category {category!r}. Please report this.')
         for destination_port in destination_ports:
             ev = self.new_event(event)
             ev['destination.port'] = destination_port
