@@ -17,7 +17,6 @@ data_type: string
 
 """
 import csv
-import io
 import json
 import re
 from typing import Optional, Union, Iterable
@@ -28,6 +27,7 @@ from intelmq.lib import utils
 from intelmq.lib.bot import ParserBot
 from intelmq.lib.exceptions import InvalidArgument, InvalidValue
 from intelmq.lib.harmonization import DateTime
+from intelmq.lib.utils import RewindableFileHandle
 
 TIME_CONVERSIONS = {'timestamp': DateTime.from_timestamp,
                     'windows_nt': DateTime.from_windows_nt,
@@ -52,7 +52,7 @@ class GenericCsvParserBot(ParserBot):
     time_format = None
     type: Optional[str] = None
     type_translation = {}
-    skip_header: bool = False
+    skip_header: Union[bool, int] = False
 
     def init(self):
         # convert columns to an array
@@ -86,6 +86,10 @@ class GenericCsvParserBot(ParserBot):
             raise ValueError("Length of parameters 'columns' (%d) and 'columns_required' (%d) "
                              "needs to be equal." % (len(self.columns), len(self.columns_required)))
 
+        if self.type:
+            # TODO remove in the next major release
+            self.default_fields["classification.type"] = self.type
+
         self.compose = self.compose_fields or {}
 
     def parse(self, report):
@@ -97,12 +101,16 @@ class GenericCsvParserBot(ParserBot):
         raw_report = re.sub(r'(?m)\0', '', raw_report)
         # ignore lines having mix of spaces and tabs only
         raw_report = re.sub(r'(?m)^[ \t]*\n?', '', raw_report)
-        # skip header
-        if self.skip_header:
-            self.tempdata.append(raw_report[:raw_report.find('\n')])
-            raw_report = raw_report[raw_report.find('\n') + 1:]
-        for row in csv.reader(io.StringIO(raw_report),
+
+        report_io = self._get_io_and_save_line_ending(raw_report)
+
+        for _ in range(int(self.skip_header)):
+            self.tempdata.append(next(report_io).rstrip(''.join(report_io.newlines)))
+
+        self._handle = RewindableFileHandle(report_io)
+        for row in csv.reader(self._handle,
                               delimiter=str(self.delimiter)):
+            self._current_line = self._handle.current_line
 
             if self.filter_text and self.filter_type:
                 text_in_row = self.filter_text in self.delimiter.join(row)
@@ -115,7 +123,7 @@ class GenericCsvParserBot(ParserBot):
             else:
                 yield row
 
-    def parse_line(self, row, report):
+    def parse_line(self, row: list, report):
         event = self.new_event(report)
 
         for keygroup, value, required in zip(self.columns, row, self.columns_required):
@@ -161,8 +169,6 @@ class GenericCsvParserBot(ParserBot):
         for key, value in self.compose.items():
             event[key] = value.format(*row)
 
-        if self.type is not None and "classification.type" not in event:
-            event.add('classification.type', self.type)
         event.add("raw", self.recover_line(row))
         yield event
 
