@@ -9,60 +9,65 @@ Parses CTIP data in JSON format.
 Key indicatorexpirationdatetime is ignored, meaning is unknown.
 
 There are two different variants of data
-1. Interflow format: JSON format, MAPPING
-2. Azure format: JSON stream format, a short example structure:
-  "DataFeed": "CTIP-Infected",
-  "SourcedFrom": "SinkHoleMessage|SensorMessage"",
-  "DateTimeReceivedUtc": nt time
-  "DateTimeReceivedUtcTxt": human readable
-  "Malware":
-  "ThreatCode": "B67-SS-TINBA",
-  "ThreatConfidence": "High|Medium|Low|Informational", -> 100/50/20/10
-  "TotalEncounters": 3,
-  "TLP": "Amber",
-  "SourceIp":
-  "SourcePort":
-  "DestinationIp":
-  "DestinationPort":
-  "TargetIp": Deprecated, so we gonne ignore it
-  "TargetPort": Deprecated, so we gonne ignore it
-  "SourceIpInfo": {
-    "SourceIpAsnNumber":
-    "SourceIpAsnOrgName":
-    "SourceIpCountryCode":
-    "SourceIpRegion":
-    "SourceIpCity"
-    "SourceIpPostalCode"
-    "SourceIpLatitude"
-    "SourceIpLongitude"
-    "SourceIpMetroCode"
-    "SourceIpAreaCode"
-    "SourceIpConnectionType"
-  },
-  "HttpInfo": {
-    "HttpHost": "",
-    "HttpRequest": "",
-    "HttpMethod": "",
-    "HttpReferrer": "",
-    "HttpUserAgent": "",
-    "HttpVersion": ""
-  },
-  "CustomInfo": {
-    "CustomField1": "",
-    "CustomField2": "",
-    "CustomField3": "",
-    "CustomField4": "",
-    "CustomField5": ""
-  },
-  "Payload": base64 encoded json
-}
+
+* Interflow format: JSON format, MAPPING
+* Azure format: JSON stream format, a short example structure:
+
+    .. code-block:: json
+
+       {
+         "DataFeed": "CTIP-Infected",
+         "SourcedFrom": "SinkHoleMessage|SensorMessage"",
+         "DateTimeReceivedUtc": nt time
+         "DateTimeReceivedUtcTxt": human readable
+         "Malware":
+         "ThreatCode": "B67-SS-TINBA",
+         "ThreatConfidence": "High|Medium|Low|Informational", -> 100/50/20/10
+         "TotalEncounters": 3,
+         "TLP": "Amber",
+         "SourceIp":
+         "SourcePort":
+         "DestinationIp":
+         "DestinationPort":
+         "TargetIp": Deprecated, so we gonne ignore it
+         "TargetPort": Deprecated, so we gonne ignore it
+         "SourceIpInfo": {
+           "SourceIpAsnNumber":
+           "SourceIpAsnOrgName":
+           "SourceIpCountryCode":
+           "SourceIpRegion":
+           "SourceIpCity"
+           "SourceIpPostalCode"
+           "SourceIpLatitude"
+           "SourceIpLongitude"
+           "SourceIpMetroCode"
+           "SourceIpAreaCode"
+           "SourceIpConnectionType"
+         },
+         "HttpInfo": {
+           "HttpHost": "",
+           "HttpRequest": "",
+           "HttpMethod": "",
+           "HttpReferrer": "",
+           "HttpUserAgent": "",
+           "HttpVersion": ""
+         },
+         "CustomInfo": {
+           "CustomField1": "",
+           "CustomField2": "",
+           "CustomField3": "",
+           "CustomField4": "",
+           "CustomField5": ""
+         },
+         "Payload": base64 encoded json with meaningful dictionary keys or JSON-string with numbered dictionary keys
+       }
 
 """
 import json
 
 import intelmq.lib.utils as utils
 from intelmq.lib.bot import ParserBot
-from intelmq.lib.harmonization import DateTime
+from intelmq.lib.harmonization import DateTime, FQDN
 
 INTERFLOW = {"additionalmetadata": "extra.additionalmetadata",
              "description": "event_description.text",
@@ -200,15 +205,20 @@ CONFIDENCE = {
 
 class MicrosoftCTIPParserBot(ParserBot):
     """Parse JSON data from Microsoft's CTIP program"""
+    overwrite: bool = True  # overwrite existing fields
 
     def parse(self, report):
         raw_report = utils.base64_decode(report.get("raw"))
         if raw_report.startswith('['):
+            # Interflow
             self.recover_line = self.recover_line_json
             yield from self.parse_json(report)
         elif raw_report.startswith('{'):
+            # Azure
             self.recover_line = self.recover_line_json_stream
             yield from self.parse_json_stream(report)
+        else:
+            raise ValueError("Can't parse the received message. It is neither a JSON list nor a JSON dictionary. Please report this bug.")
 
     def parse_line(self, line, report):
         if line.get('version', None) == 1.5:
@@ -216,7 +226,7 @@ class MicrosoftCTIPParserBot(ParserBot):
         else:
             yield from self.parse_azure(line, report)
 
-    def parse_interflow(self, line, report):
+    def parse_interflow(self, line: dict, report):
         raw = self.recover_line(line)
         if line['indicatorthreattype'] != 'Botnet':
             raise ValueError('Unknown indicatorthreattype %r, only Botnet is supported.' % line['indicatorthreattype'])
@@ -251,23 +261,34 @@ class MicrosoftCTIPParserBot(ParserBot):
         yield event
 
     def parse_azure(self, line, report):
-        raw = self.recover_line(line)
+        raw = self.recover_line()
 
         event = self.new_event(report)
 
         for key, value in line.copy().items():
             if key == 'Payload':
+                # empty
                 if value == 'AA==':  # NULL
                     del line[key]
                     continue
-                try:
-                    value = json.loads(utils.base64_decode(value))
-                    # continue unpacking in next loop
-                except json.decoder.JSONDecodeError:
-                    line[key] = utils.base64_decode(value)
+
+                # JSON string
+                if value.startswith('{'):
+                    for payload_key, payload_value in json.loads(value).items():
+                        event[f'extra.payload.{payload_key}'] = payload_value
+                    del line[key]
+                else:
+                    # base64-encoded JSON
+                    try:
+                        value = json.loads(utils.base64_decode(value))
+                        # continue unpacking in next loop
+                    except json.decoder.JSONDecodeError:
+                        line[key] = utils.base64_decode(value)
+            elif key == 'TLP' and value.lower() == 'unknown':
+                del line[key]
             if isinstance(value, dict):
                 for subkey, subvalue in value.items():
-                    line['%s.%s' % (key, subkey)] = subvalue
+                    line[f'{key}.{subkey}'] = subvalue
                 del line[key]
         for key, value in line.items():
             if key == 'ThreatConfidence':
@@ -281,11 +302,17 @@ class MicrosoftCTIPParserBot(ParserBot):
             elif key == 'Payload.Protocol':
                 payload_protocol = value[:value.find('/')]
                 if payload_protocol:
+                    # needs to overwrite a field previously parsed and written
                     event.add('protocol.application', payload_protocol, overwrite=True)  # "HTTP/1.1", save additionally
+            elif key == 'Payload.domain':
+                # Sometimes the destination address is also given as domain, ignore it here as we already save it as destination.ip (see https://github.com/certtools/intelmq/pull/2144)
+                if not FQDN.is_valid(value) and value == line.get('Payload.serverIp'):
+                    continue
             elif not value:
                 continue
             if AZURE[key] != '__IGNORE__':
-                event.add(AZURE[key], value, overwrite=True)
+                # feed.accuracy is calculated newly and always needs to be overwritten
+                event.add(AZURE[key], value, overwrite=self.overwrite or AZURE[key] == "feed.accuracy")
         event.add('classification.type', 'infected-system')
         event.add('raw', raw)
         yield event
