@@ -8,10 +8,10 @@ from datetime import datetime
 from urllib.parse import urljoin
 
 from intelmq.lib import utils
-from intelmq.lib.bot import Bot
+from intelmq.lib.bot import ParserBot
 
 
-class MISPParserBot(Bot):
+class MISPParserBot(ParserBot):
     """Parse MISP events"""
 
     # Taxonomy library from ecsirt (default in MISP)
