@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2016 jgedeon120
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """ IntelMQ parser for Netlab 360 data feeds. """
 
@@ -6,6 +10,7 @@ from intelmq.lib.harmonization import DateTime
 
 
 class Netlab360ParserBot(ParserBot):
+    """Parse the Netlab 360 DGA, Hajime, Magnitude and Mirai feeds"""
     DGA_FEED = {'http://data.netlab.360.com/feeds/dga/dga.txt',
                 'https://data.netlab.360.com/feeds/dga/dga.txt'}
     MAGNITUDE_FEED = {'http://data.netlab.360.com/feeds/ek/magnitude.txt',
@@ -33,7 +38,7 @@ class Netlab360ParserBot(ParserBot):
                 event.add('time.source', value[2] + ' UTC')
                 if event['time.source'] > event['time.observation']:
                     event.change('time.source', event['time.observation'])
-                event.add('classification.type', 'c2server')
+                event.add('classification.type', 'c2-server')
                 event.add('event_description.url', 'http://data.netlab.360.com/dga')
 
             elif report['feed.url'] in Netlab360ParserBot.MAGNITUDE_FEED:
