@@ -22,9 +22,11 @@ from intelmq.lib import utils
 
 __all__ = ['Event', 'Message', 'MessageFactory', 'Report']
 VALID_MESSSAGE_TYPES = ('Event', 'Message', 'Report')
+# '_' needs to be allowed at the beginning currently because of '__type'. Can be removed with IEP04 implemented.
+HARMONIZATION_KEY_FORMAT = re.compile(r'^[a-z_][a-z_0-9]+(\.[a-z_0-9]+)*$')
 
 
-class MessageFactory(object):
+class MessageFactory:
     """
     unserialize: JSON encoded message to object
     serialize: object to JSON encoded object
@@ -116,7 +118,7 @@ class Message(dict):
                           "This assumption will be removed in version 3.0.", DeprecationWarning)
             self.harmonization_config['extra']['type'] = 'JSONDict'
         for harm_key in self.harmonization_config.keys():
-            if not re.match('^[a-z_](.[a-z_0-9]+)*$', harm_key) and harm_key != '__type':
+            if not HARMONIZATION_KEY_FORMAT.match(harm_key) and harm_key != '__type':
                 raise exceptions.InvalidKey("Harmonization key %r is invalid." % harm_key)
 
         super().__init__()
@@ -273,7 +275,7 @@ class Message(dict):
                         continue
                 if key != 'extra' and extravalue in self._IGNORED_VALUES:
                     continue
-                super().__setitem__('{}.{}'.format(key, extrakey),
+                super().__setitem__(f'{key}.{extrakey}',
                                     extravalue)
         else:
             super().__setitem__(key, value)
@@ -326,8 +328,10 @@ class Message(dict):
             class_name, subitem = self.__get_type_config(key)
         except KeyError:
             return False
-        if key in self.harmonization_config or key == '__type' or subitem:
+        if key in self.harmonization_config or key == '__type':
             return True
+        if subitem:
+            return HARMONIZATION_KEY_FORMAT.match(key)
         return False
 
     def __is_valid_value(self, key: str, value: str):
@@ -426,7 +430,7 @@ class Message(dict):
             jsondict_as_string:
                 If False (default) treat values in JSONDict fields just as normal ones
                 If True, save such fields as JSON-encoded string. This is the old behavior
-                    before version 1.1.
+                before version 1.1.
 
         Returns:
             new_dict: A dictionary as copy of itself modified according
