@@ -19,38 +19,38 @@ import base64
 import collections
 import grp
 import gzip
+import importlib
+import inspect
 import io
 import json
 import logging
 import logging.handlers
 import os
+import pathlib
 import pwd
 import re
-import requests
-import shutil
 import sys
 import tarfile
-import traceback
-import warnings
-import zipfile
-from typing import Any, Dict, Generator, Iterator, Optional, Sequence, Union
-from pathlib import Path
-import importlib
-import inspect
-import pathlib
 import textwrap
-from pkg_resources import resource_filename
+import traceback
+import zipfile
+from pathlib import Path
+from typing import (Any, Callable, Dict, Generator, Iterator, Optional,
+                    Sequence, Union)
 
 import dateutil.parser
+import dns.resolver
+import dns.version
+import requests
 from dateutil.relativedelta import relativedelta
-from termstyle import red
+from pkg_resources import resource_filename
 from ruamel.yaml import YAML
+from ruamel.yaml.scanner import ScannerError
+from termstyle import red
 
 import intelmq
-from intelmq.lib.exceptions import DecodingError
 from intelmq import RUNTIME_CONF_FILE
-
-yaml = YAML(typ="unsafe", pure=True)
+from intelmq.lib.exceptions import DecodingError
 
 __all__ = ['base64_decode', 'base64_encode', 'decode', 'encode',
            'load_configuration', 'load_parameters', 'log', 'parse_logline',
@@ -79,7 +79,7 @@ SYSLOG_REGEX = (r'^(?P<date>\w{3} \d{2} \d{2}:\d{2}:\d{2}) (?P<hostname>[-\.\w]+
 RESPONSE_FILENAME = re.compile("filename=(.+)")
 
 
-class Parameters(object):
+class Parameters:
     pass
 
 
@@ -212,8 +212,14 @@ def load_configuration(configuration_filepath: str) -> dict:
         ValueError: if file not found
     """
     if os.path.exists(configuration_filepath):
-        with open(configuration_filepath, 'r') as fpconfig:
-            config = yaml.load(fpconfig)
+        with open(configuration_filepath) as fpconfig:
+            try:
+                config = YAML(typ="unsafe", pure=True).load(fpconfig)
+            except ScannerError as exc:
+                if "found character '\\t' that cannot start any token" in exc.problem:
+                    fpconfig.seek(0)
+                    return json.load(fpconfig)
+                raise
     else:
         raise ValueError('File not found: %r.' % configuration_filepath)
     return config
@@ -249,7 +255,7 @@ def write_configuration(configuration_filepath: str,
         pathlib.Path(configuration_filepath + '.bak').write_text(config.read_text())
     with open(configuration_filepath, 'w') as handle:
         if useyaml:
-            yaml.dump(content, handle)
+            YAML(typ="unsafe", pure=True).dump(content, handle)
         else:
             json.dump(content, fp=handle, indent=4,
                       sort_keys=True,
@@ -373,7 +379,7 @@ def log(name: str, log_path: Union[str, bool] = intelmq.DEFAULT_LOGGING_PATH,
         logging_level_stream = log_level
 
     if log_path and not syslog:
-        handler = RotatingFileHandler("%s/%s.log" % (log_path, name),
+        handler = RotatingFileHandler(f"{log_path}/{name}.log",
                                       maxBytes=log_max_size if log_max_size else 0,
                                       backupCount=log_max_copies)
         handler.setLevel(log_level)
@@ -609,22 +615,24 @@ def unzip(file: bytes, extract_files: Union[bool, list], logger=None,
                 if filename in extract_files)
 
 
-class RewindableFileHandle(object):
+class RewindableFileHandle:
     """
     Can be used for easy retrieval of last input line to populate raw field
-    during CSV parsing.
+    during CSV parsing and handling filtering.
     """
 
-    def __init__(self, f):
+    def __init__(self, f, condition: Optional[Callable] = lambda _: True):
         self.f = f
         self.current_line: Optional[str] = None
         self.first_line: Optional[str] = None
 
+        self._iterator = filter(condition, self.f)
+
     def __iter__(self):
         return self
 
     def __next__(self):
-        self.current_line = next(self.f)
+        self.current_line = next(self._iterator)
         if self.first_line is None:
             self.first_line = self.current_line
         return self.current_line
@@ -661,7 +669,7 @@ def seconds_to_human(seconds: int, precision: int = 0) -> str:
     result = []
     for frame in ('days', 'hours', 'minutes', 'seconds'):
         if getattr(relative, frame):
-            result.append('%.{}f%s'.format(precision) % (getattr(relative, frame), frame[0]))
+            result.append(f'%.{precision}f%s' % (getattr(relative, frame), frame[0]))
     return ' '.join(result)
 
 
@@ -852,7 +860,11 @@ def list_all_bots() -> dict:
     botfiles = [botfile for botfile in pathlib.Path(base_path).glob('**/*.py') if botfile.is_file() and botfile.name != '__init__.py']
     for file in botfiles:
         file = Path(file.as_posix().replace(base_path, 'intelmq/bots'))
-        mod = importlib.import_module('.'.join(file.with_suffix('').parts))
+        try:
+            mod = importlib.import_module('.'.join(file.with_suffix('').parts))
+        except SyntaxError:
+            # Skip invalid bots
+            continue
         if hasattr(mod, 'BOT'):
             name = mod.BOT.__name__
             keys = {}
@@ -869,7 +881,7 @@ def list_all_bots() -> dict:
 
             bots[file.parts[2].capitalize()[:-1]][name] = {
                 "module": mod.__name__,
-                "description": "Missing description" if not getattr(mod.BOT, '__doc__', None) else textwrap.dedent(mod.BOT.__doc__),
+                "description": "Missing description" if not getattr(mod.BOT, '__doc__', None) else textwrap.dedent(mod.BOT.__doc__).strip(),
                 "parameters": keys,
             }
     return bots
@@ -909,3 +921,16 @@ def get_bots_settings(bot_id: str = None) -> dict:
     if 'global' in runtime_conf:
         del runtime_conf['global']
     return runtime_conf
+
+
+def resolve_dns(*args, **kwargs) -> dns.resolver.Answer:
+    """Resolve DNS query using the method recommended according to the installed dnspython version
+
+    Parameters:
+        see: https://dnspython.readthedocs.io/en/stable/resolver-class.html#dns.resolver.Resolver.resolve
+        The `search` parameter is always set to True for compatibility with dnspython version 1.
+
+    """
+    if dns.version.MAJOR < 2:
+        return dns.resolver.query(*args, **kwargs)
+    return dns.resolver.resolve(*args, **kwargs, search=True)
