@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 
 import unittest
@@ -6,8 +10,8 @@ import intelmq.lib.test as test
 from intelmq.bots.experts.reverse_dns.expert import ReverseDnsExpertBot
 
 EXAMPLE_INPUT = {"__type": "Event",
-                 "source.ip": "192.0.43.7",  # icann.org
-                 "destination.ip": "192.0.43.8",  # iana.org
+                 "source.ip": "192.0.43.7",  # icann.org.
+                 "destination.ip": "192.0.43.8",  # iana.org.
                  "time.observation": "2015-01-01T00:00:00+00:00",
                  }
 EXAMPLE_OUTPUT = {"__type": "Event",
@@ -16,7 +20,7 @@ EXAMPLE_OUTPUT = {"__type": "Event",
                   "destination.ip": "192.0.43.8",
                   "destination.reverse_dns": "icann.org",
                   # manual verification shows another result:
-                  # "destination.reverse_dns": "43-8.any.icann.org",
+                  # "destination.reverse_dns": "43-8.any.icann.org.",       # pretty weird!
                   "time.observation": "2015-01-01T00:00:00+00:00",
                   }
 EXAMPLE_INPUT6 = {"__type": "Event",
@@ -29,14 +33,6 @@ EXAMPLE_OUTPUT6 = {"__type": "Event",
                    "source.reverse_dns": "iana.org",
                    "time.observation": "2015-01-01T00:00:00+00:00",
                    }
-INVALID_PTR_INP = {"__type": "Event",
-                   "source.ip": "31.210.115.39",  # PTR is '.'
-                   "time.observation": "2015-01-01T00:00:00+00:00",
-                   }
-INVALID_PTR_OUT = {"__type": "Event",
-                   "source.ip": "31.210.115.39",
-                   "time.observation": "2015-01-01T00:00:00+00:00",
-                   }
 INVALID_PTR_INP2 = {"__type": "Event",
                     "source.ip": "5.157.80.221",  # PTR is '5.157.80.221.' and 'aliancys.peopleinc.nl.'
                     "time.observation": "2015-01-01T00:00:00+00:00",
@@ -78,11 +74,6 @@ class TestReverseDnsExpertBot(test.BotTestCase, unittest.TestCase):
         self.run_bot()
         self.assertMessageEqual(0, EXAMPLE_OUTPUT6)
 
-    def test_invalid_ptr(self):
-        self.input_message = INVALID_PTR_INP
-        self.run_bot()
-        self.assertMessageEqual(0, INVALID_PTR_OUT)
-
     def test_invalid_ptr2(self):
         self.input_message = INVALID_PTR_INP2
         self.run_bot()
