@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2017 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import os.path
 import unittest
@@ -16,6 +20,8 @@ with open(os.path.join(os.path.dirname(__file__), 'example_report_dns.json')) as
     EXAMPLE_DNS_RAW = handle.read()
 with open(os.path.join(os.path.dirname(__file__), 'example_report_ignore.json')) as handle:
     EXAMPLE_IGNORE_RAW = handle.read()
+with open(os.path.join(os.path.dirname(__file__), 'example_comm_http_host_not_dst_ip.json')) as handle:
+    EXAMPLE_COMM_HTTP_HOST_NOT_DST_IP_RAW = handle.read()
 
 
 EXAMPLE_REPORT = {"feed.url": "https://prod.cyberfeed.net/stream?key=7b7cd29c7a424b2980ca",
@@ -25,8 +31,9 @@ EXAMPLE_REPORT = {"feed.url": "https://prod.cyberfeed.net/stream?key=7b7cd29c7a4
                   "raw": utils.base64_encode(EXAMPLE_RAW),
                   "time.observation": "2016-04-19T23:16:08+00:00"
                   }
-EXAMPLE_EVENT  = {"classification.taxonomy": "malicious code",
-                  "classification.type": "malware",
+
+EXAMPLE_EVENT  = {"classification.taxonomy": "malicious-code",
+                  "classification.type": "infected-system",
                   "destination.port": 80,
                   "feed.accuracy": 100.0,
                   "malware.name": "nivdort",
@@ -61,7 +68,7 @@ EXAMPLE_REPORT2 = {"feed.name": "AnubisNetworks",
                    "time.observation":
                    "2016-04-19T23:16:10+00:00"
                    }
-EXAMPLE_EVENT2  = {"classification.taxonomy": "malicious code",
+EXAMPLE_EVENT2  = {"classification.taxonomy": "malicious-code",
                    "feed.name": "AnubisNetworks",
                    "malware.name": "spyapp",
                    "destination.fqdn": "example.net",
@@ -77,7 +84,7 @@ EXAMPLE_EVENT2  = {"classification.taxonomy": "malicious code",
                    "destination.port": 80,
                    "feed.accuracy": 100.0,
                    "raw": EXAMPLE_REPORT2['raw'],
-                   "classification.type": "malware",
+                   "classification.type": "infected-system",
                    "event_description.text": "Sinkhole attempted connection"
                    }
 
@@ -86,7 +93,7 @@ EXAMPLE_REPORT3 = {"feed.url": "https://prod.cyberfeed.net/stream?key=7b7cd29c7a
                    "__type": "Report",
                    "time.observation": "2016-04-19T23:16:10+00:00"
                    }
-EXAMPLE_EVENT3  = {"classification.taxonomy": "malicious code",
+EXAMPLE_EVENT3  = {"classification.taxonomy": "malicious-code",
                    "malware.name": "malwname",
                    "source.ip": "203.0.113.2",
                    "source.port": 59645,
@@ -97,7 +104,7 @@ EXAMPLE_EVENT3  = {"classification.taxonomy": "malicious code",
                    "destination.ip": "203.0.113.1",
                    "destination.port": 80,
                    "raw": EXAMPLE_REPORT3['raw'],
-                   "classification.type": "malware",
+                   "classification.type": "infected-system",
                    "event_description.text": "Sinkhole attempted connection",
                    "extra.metadata.flowbits": [
                            "_mt_s",
@@ -166,17 +173,17 @@ EXAMPLE_EVENT3  = {"classification.taxonomy": "malicious code",
                    'extra.communication.http.host.geolocation.latitude': 37.751,
                    'extra.communication.http.host.geolocation.longitude': -97.822,
                    'extra.communication.http.host.network': '203.0.113.4/21',
-                   "extra.communication.http.x_forwarded_for_#1.network": "10.26.116.22/24",
-                   "extra.communication.http.x_forwarded_for_#1.geolocation.cc": "AT",
-                   "extra.communication.http.x_forwarded_for_#1.geolocation.country": "Austria",
-                   "extra.communication.http.x_forwarded_for_#1.geolocation.region": "Salzburg",
-                   "extra.communication.http.x_forwarded_for_#1.geolocation.region_code": "05",
-                   "extra.communication.http.x_forwarded_for_#1.geolocation.city": "Salzburg",
-                   "extra.communication.http.x_forwarded_for_#1.geolocation.postal_code": "5020",
-                   "extra.communication.http.x_forwarded_for_#1.geolocation.latitude": 47.8007,
-                   "extra.communication.http.x_forwarded_for_#1.geolocation.longitude": 13.0442,
-                   "extra.communication.http.x_forwarded_for_#1.asn": 1901,
-                   "extra.communication.http.x_forwarded_for_#1.as_name": "Example AS",
+                   "extra.communication.http.x_forwarded_for_1.network": "10.26.116.22/24",
+                   "extra.communication.http.x_forwarded_for_1.geolocation.cc": "AT",
+                   "extra.communication.http.x_forwarded_for_1.geolocation.country": "Austria",
+                   "extra.communication.http.x_forwarded_for_1.geolocation.region": "Salzburg",
+                   "extra.communication.http.x_forwarded_for_1.geolocation.region_code": "05",
+                   "extra.communication.http.x_forwarded_for_1.geolocation.city": "Salzburg",
+                   "extra.communication.http.x_forwarded_for_1.geolocation.postal_code": "5020",
+                   "extra.communication.http.x_forwarded_for_1.geolocation.latitude": 47.8007,
+                   "extra.communication.http.x_forwarded_for_1.geolocation.longitude": 13.0442,
+                   "extra.communication.http.x_forwarded_for_1.asn": 1901,
+                   "extra.communication.http.x_forwarded_for_1.as_name": "Example AS",
                    }
 
 
@@ -185,7 +192,7 @@ EXAMPLE_REPORT_DNS = {"feed.url": "https://prod.cyberfeed.net/stream?key=7b7cd29
                       "__type": "Report",
                       "time.observation": "2016-04-19T23:16:10+00:00"
                       }
-EXAMPLE_EVENT_DNS  = {"classification.taxonomy": "malicious code",
+EXAMPLE_EVENT_DNS  = {"classification.taxonomy": "malicious-code",
                       "malware.name": "malware name dns",
                       "source.ip": "203.0.113.2",
                       "source.port": 11138,
@@ -196,7 +203,7 @@ EXAMPLE_EVENT_DNS  = {"classification.taxonomy": "malicious code",
                       "destination.ip": "203.0.113.1",
                       "destination.port": 53,
                       "raw": EXAMPLE_REPORT_DNS['raw'],
-                      "classification.type": "malware",
+                      "classification.type": "infected-system",
                       "classification.identifier": "Malware name DNS",
                       "event_description.text": "Sinkhole attempted connection",
                       "protocol.application": "dns",
@@ -230,6 +237,57 @@ EXAMPLE_REPORT_IGNORE = {"feed.url": "https://prod.cyberfeed.net/stream?key=7b7c
                          "time.observation": "2016-04-19T23:16:10+00:00"
                          }
 
+EXAMPLE_REPORT_COMM_HTTP_HOST_NOT_DST_IP_RAW = {
+    "feed.url": "https://prod.cyberfeed.net/stream?key=7b7cd29c7a424b2980ca",
+    "raw": utils.base64_encode(EXAMPLE_COMM_HTTP_HOST_NOT_DST_IP_RAW),
+    "__type": "Report",
+    "time.observation": "2016-04-19T23:16:10+00:00"
+    }
+EXAMPLE_EVENT_COMM_HTTP_HOST_NOT_DST_IP = {
+    "__type": "Event",
+    'classification.identifier': 'BHProxies',
+    'classification.taxonomy': 'malicious-code',
+    'classification.type': 'infected-system',
+    'destination.ip': '198.18.0.1',
+    'destination.port': 2532,
+    'destination.url': 'http://192.168.0.1/',
+    'destination.urlpath': '/',
+    'event_description.text': 'Sinkhole attempted connection',
+    'extra._origin': 'infections',
+    'extra.communication.http.host.as_name': 'Example AS',
+    'extra.communication.http.host.asn': 50245,
+    'extra.communication.http.host.geolocation.cc': 'NL',
+    'extra.communication.http.host.geolocation.country': 'Netherlands',
+    'extra.communication.http.host.geolocation.latitude': 52.0,
+    'extra.communication.http.host.geolocation.longitude': 4.0,
+    'extra.communication.http.host.network': '192.168.0.1/20',
+    'extra.communication.http_host': '192.168.0.1',
+    'extra.communication.type': 'sinkhole',
+    'extra.communication.unverified_domain': 'true',
+    'extra.malware.categories': ['Proxy'],
+    'extra.malware.severity': 2,
+    'extra.request_method': 'GET',
+    'extra.source.geolocation.postal_code': '1060',
+    'extra.source.geolocation.region_code': '09',
+    'extra.user_agent': 'Long UA string',
+    'feed.url': 'https://prod.cyberfeed.net/stream',
+    'malware.name': 'bhproxies',
+    'protocol.application': 'http',
+    'raw': utils.base64_encode(EXAMPLE_COMM_HTTP_HOST_NOT_DST_IP_RAW),
+    'source.as_name': 'Example AS',
+    'source.asn': 6830,
+    'source.geolocation.cc': 'AT',
+    'source.geolocation.city': 'Vienna',
+    'source.geolocation.country': 'Austria',
+    'source.geolocation.latitude': 48.0,
+    'source.geolocation.longitude': 16.0,
+    'source.geolocation.region': 'Wien',
+    'source.ip': '10.0.0.1',
+    'source.network': '10.0.0.0/23',
+    'source.port': 58077,
+    'time.source': '2020-08-21T04:33:10+00:00',
+    }
+
 
 class TestAnubisNetworksParserBot(test.BotTestCase, unittest.TestCase):
 
@@ -271,9 +329,14 @@ class TestAnubisNetworksParserBot(test.BotTestCase, unittest.TestCase):
         """ Test empty line as input """
         self.input_message = EXAMPLE_REPORT_IGNORE
         self.run_bot()
-        print(self.get_output_queue())
         self.assertOutputQueueLen(0)
 
+    def test_example_comm_http_host_not_dst_ip(self):
+        """ Test with an example where comm.http.host is not equal to dst.ip """
+        self.input_message = EXAMPLE_REPORT_COMM_HTTP_HOST_NOT_DST_IP_RAW
+        self.run_bot()
+        self.assertMessageEqual(0, EXAMPLE_EVENT_COMM_HTTP_HOST_NOT_DST_IP)
+
 
 if __name__ == '__main__':  # pragma: no cover
     unittest.main()
