@@ -181,61 +181,74 @@ EVENTS = [{'time.source': '2019-03-22T11:18:52+00:00',
                 'protocol.transport': 'udp',
                 } for destport in [17875, 24526, 54449, 9314, 4903,
                                    1568, 20749, 30524, 59316, 60704]] + [
-          {'classification.type': 'spam',
-           'classification.identifier': 'spam',
-           'time.source': '2019-10-02T23:00:17+00:00',
-           },
-          {'time.source': '2019-10-23T12:46:18+00:00',
-           'classification.type': 'phishing',
-           'classification.identifier': 'phishing',
-           },
-          {'classification.type': 'scanner',
-           'classification.identifier': 'darknet',
-           'protocol.transport': 'nvp-ii',
-           'destination.port': 0,
-           'time.source': '2020-01-10T09:17:17+00:00',
-           },
-          {'classification.type': 'infected-system',
-           'classification.identifier': 'conficker',
-           'malware.name': 'conficker',
-           'source.port': 1997,
-           'destination.ip': '172.16.0.22',
-           'time.source': '2020-05-08T09:13:34+00:00',
-           },
-          {'classification.type': 'scanner',
-           'classification.identifier': 'scanner',
-           'time.source': '2020-07-09T03:40:15+00:00',
-           'source.account': 'pm',
-           },
-          {'classification.type': 'scanner',
-           'classification.identifier': 'darknet',
-           'time.source': '2020-10-08T02:21:26+00:00',
-           'protocol.transport': 'gre',
-           },
-          {'classification.type': 'scanner',
-           'classification.identifier': 'darknet',
-           'time.source': '2020-10-15T09:22:10+00:00',
-           'protocol.transport': 'ipv6-nonxt',
-           },
-          {
-           'classification.type': 'proxy',
-           'classification.identifier': 'openproxy',
-           'time.source': '2020-12-14T08:28:01+00:00',
-           'extra.source.asns': [64496, 212682],
-           'protocol.application': 'httpconnect',
-           'source.port': 51915,
-           },
-          {'classification.type': 'brute-force',
-           'protocol.transport': 'tcp',
-           'destination.port': 22,
-           'source.port': 16794,
-           'time.source': '2021-03-09T00:11:21+00:00',
-           },
-          ]
+    {'classification.type': 'spam',
+     'classification.identifier': 'spam',
+     'time.source': '2019-10-02T23:00:17+00:00',
+     },
+    {'time.source': '2019-10-23T12:46:18+00:00',
+     'classification.type': 'phishing',
+     'classification.identifier': 'phishing',
+     },
+    {'classification.type': 'scanner',
+     'classification.identifier': 'darknet',
+     'protocol.transport': 'nvp-ii',
+     'destination.port': 0,
+     'time.source': '2020-01-10T09:17:17+00:00',
+     },
+    {'classification.type': 'infected-system',
+     'classification.identifier': 'conficker',
+     'malware.name': 'conficker',
+     'source.port': 1997,
+     'destination.ip': '172.16.0.22',
+     'time.source': '2020-05-08T09:13:34+00:00',
+     },
+    {'classification.type': 'scanner',
+     'classification.identifier': 'scanner',
+     'time.source': '2020-07-09T03:40:15+00:00',
+     'source.account': 'pm',
+     },
+    {'classification.type': 'scanner',
+     'classification.identifier': 'darknet',
+     'time.source': '2020-10-08T02:21:26+00:00',
+     'protocol.transport': 'gre',
+     },
+    {'classification.type': 'scanner',
+     'classification.identifier': 'darknet',
+     'time.source': '2020-10-15T09:22:10+00:00',
+     'protocol.transport': 'ipv6-nonxt',
+     },
+    {
+        'classification.type': 'proxy',
+        'classification.identifier': 'openproxy',
+        'time.source': '2020-12-14T08:28:01+00:00',
+        'extra.source.asns': [64496, 212682],
+        'protocol.application': 'httpconnect',
+        'source.port': 51915,
+    },
+    {'classification.type': 'brute-force',
+     'protocol.transport': 'tcp',
+     'destination.port': 22,
+     'source.port': 16794,
+     'time.source': '2021-03-09T00:11:21+00:00',
+     },
+    {'time.source': '2019-03-22T18:18:52+00:00',
+     'classification.type': 'infected-system',
+     'classification.identifier': 'conficker',
+     'malware.name': 'conficker',
+     'source.geolocation.cc': 'AT',
+     },
+    {'time.source': '2019-03-22T20:18:52+00:00',
+     'classification.type': 'infected-system',
+     'classification.identifier': 'conficker',
+     'malware.name': 'conficker',
+     'source.fqdn': '21-0-16-172.example.tld',
+     'source.geolocation.cc': 'AT',
+     },
+]
 
 # The number of events a single line in the raw data produces
 NUM_EVENTS = (1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-              1, 1, 10, 1, 1, 1, 1, 1, 1, 1, 1, 1)
+              1, 1, 10, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1)
 RAWS = []
 for i, line in enumerate(RAW_LINES[3:]):
     for count in range(NUM_EVENTS[i]):
