@@ -27,8 +27,8 @@ EVENTS = [{'__type': 'Event',
            'classification.taxonomy': 'other',
            'classification.type': 'other',
            'classification.identifier': 'accessible-http',
-           'extra.naics': 518111,
-           'extra.sic': 737401,
+           'extra.source.naics': 518111,
+           'extra.source.sic': 737401,
            'extra.http': 'HTTP/1.1',
            'extra.http_code': 200,
            'extra.http_reason': 'OK',
@@ -37,7 +37,8 @@ EVENTS = [{'__type': 'Event',
            'extra.transfer_encoding': 'chunked',
            'extra.http_date': '2018-04-19T00:02:28+00:00',
            'extra.tag': 'http',
-					 'protocol.transport': 'tcp',
+           'protocol.application': 'http',
+	   'protocol.transport': 'tcp',
            'raw': utils.base64_encode('\n'.join([EXAMPLE_LINES[0],
                                                  EXAMPLE_LINES[1]])),
            'source.reverse_dns': 'c-75-74-78-113.hsd1.fl.comcast.net',
@@ -54,8 +55,8 @@ EVENTS = [{'__type': 'Event',
            'classification.taxonomy': 'other',
            'classification.type': 'other',
            'classification.identifier': 'accessible-http',
-           'extra.naics': 518210,
-           'extra.sic': 737415,
+           'extra.source.naics': 518210,
+           'extra.source.sic': 737415,
            'extra.http': 'HTTP/1.1',
            'extra.http_code': 200,
            'extra.http_reason': 'OK',
@@ -64,6 +65,7 @@ EVENTS = [{'__type': 'Event',
            'extra.http_date': '2018-04-19T02:02:28+00:00',
            'extra.tag': 'http',
            'protocol.transport': 'tcp',
+           'protocol.application': 'http',
            'raw': utils.base64_encode('\n'.join([EXAMPLE_LINES[0],
                                                  EXAMPLE_LINES[2]])),
            'source.reverse_dns': 'sto95-3-88-162-174-130.fbx.proxad.net',
