@@ -38,7 +38,7 @@ EVENTS = [{'__type': 'Event',
            "extra.run_id": "d440b0b2fb3d1db655ad607e11e6f38011a0f599",
            "extra.sic": 737999,
            "extra.tag": "redis",
-           "extra.uptime": "27946314",
+           "extra.uptime": 27946314,
            "extra.version": "2.8.19",
            "protocol.application": "redis",
            "protocol.transport": "tcp",
@@ -68,7 +68,7 @@ EVENTS = [{'__type': 'Event',
            "extra.process_id": "343519",
            "extra.run_id": "53d63f23511dc0080b49aaa8e8203d65619f1c8c",
            "extra.tag": "redis",
-           "extra.uptime": "310556",
+           "extra.uptime": 310556,
            "extra.version": "3.0.6",
            "protocol.application": "redis",
            "protocol.transport": "tcp",
