@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2020 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """
 Testing the IntelMQ-specific exceptions
@@ -20,9 +24,6 @@ class TestUtils(unittest.TestCase):
                 raise excs.PipelineError(exc)
         except excs.PipelineError as exc:
             exception = exc
-        if sys.version_info < (3, 7):
-            self.assertEqual(exception.args, ('pipeline failed - ValueError(%r,)' % message, ))
-        else:
             self.assertEqual(exception.args, ('pipeline failed - ValueError(%r)' % message, ))
 
         message = 'some error'
